Imports System.Security.Principal
Imports System.Data.SqlClient

''' <summary>
''' Security Namespace 
''' </summary>
Namespace Security

  ''' <summary>
  ''' Implements a custom Identity class that supports a Table Driven Role Attribute.
  ''' </summary>
    Public Class SecurityIdentity
        Implements IIdentity

#Region "Private Variables"
        Private mUsername As String
        Private mRoles As New ArrayList
#End Region

#Region "Private Constructor"
        ''' <summary>Prevent Direct Creation. A New Security Object can only be created by the LoadIdentity Function</summary>
        Private Sub New()
        End Sub
#End Region

#Region " IIdentity Implementations "

        ''' <summary>
        ''' Implements the IsAuthenticated property defined by IIdentity.
        ''' </summary>
        Public ReadOnly Property IsAuthenticated() As Boolean Implements IIdentity.IsAuthenticated
            Get
                Return Len(mUsername) > 0
            End Get
        End Property

        ''' <summary>
        ''' Implements the AuthenticationType property defined by IIdentity.
        ''' </summary>
        Public ReadOnly Property AuthenticationType() As String Implements IIdentity.AuthenticationType
            Get
                Return "Custom Authenication"
            End Get
        End Property

        ''' <summary>
        ''' Implements the Name property defined by IIdentity.
        ''' </summary>
        Public ReadOnly Property Name() As String Implements IIdentity.Name
            Get
                Return mUsername
            End Get
        End Property

#End Region

#Region "IsInRole Function"
        Friend Function IsInRole(ByVal Role As String) As Boolean
            Return mRoles.Contains(Role)
        End Function
#End Region

#Region " Create and Load "
        Friend Shared Function LoadMembersIdentity(ByVal UserName As String, ByVal Password As String) As SecurityIdentity
            Dim SecID As New SecurityIdentity
            SecID.DBSelect(UserName, Password)
            Return SecID
        End Function

#End Region

#Region " Data access "

        ''' <summary>
        ''' Retrieves the identity data(Roles) from the Database for a specific user.
        ''' </summary>
        Private Function DBSelect(ByVal UserName As String, ByVal UserPwd As String) As SecurityIdentity
            mRoles.Clear()

            If ApplicationSettings.IsAdmin(UserName, UserPwd) Then
                mRoles.Add("Admin")
            End If

            mUsername = UserName
             
        End Function

#End Region

    End Class

End Namespace
