Imports System
Imports System.IO
Imports System.Web
Imports System.Configuration
Imports System.Text
Imports System.Collections.Specialized
Imports System.Text.RegularExpressions
Imports System.Data
Imports System.Data.SqlClient


Namespace Utility



#Region "Configuration Section Handler Class"

'*********************************************************************
' ConfigurationSectionHandler Class
' Inherits from the NameValueFileSectionHandler so that fully
' qualified assembly name can be avoided in the Web.Config file.
'*********************************************************************
Public Class ConfigurationSectionHandler
    Inherits System.Configuration.NameValueFileSectionHandler
End Class 'ConfigurationSectionHandler

#End Region


#Region "Configuration Handler Class"
'*********************************************************************
' ConfigurationHandler Class
'
' This class contains common utility methods used throughout 
' the Application such as retreiving database connections,
' determinig whose logged in, etc
'*********************************************************************
Public Class ConfigurationHandler


    '*********************************************************************
    ' Current Config Property
    ' Represents the current configuration that the application should use.
    '(Production OR Development)
    '*********************************************************************
    Public Shared ReadOnly Property CurrentConfig() As String
        Get
            'Return "Development"
            'Return "Production"
            Return ConfigurationSettings.AppSettings.Item("CurrentConfig")
        End Get
    End Property

    '*********************************************************************
    ' AppPath Property
    ' Represents the path of the current application.
    '*********************************************************************
    Public Shared ReadOnly Property AppPath() As String
        Get
            If HttpContext.Current.Request.ApplicationPath = "/" Then
                Return String.Empty
            End If
            Return HttpContext.Current.Request.ApplicationPath
        End Get
    End Property

    '*********************************************************************
    ' Application DataBase Connection String Property
    ' Returns connection string for connecting to the application database
    '*********************************************************************
    Public Shared ReadOnly Property AppDBConnectionString() As String
        Get
            Dim nvc As NameValueCollection = CType(ConfigurationSettings.GetConfig("Config" & ConfigurationHandler.CurrentConfig & "/database"), NameValueCollection)
            'Return nvc("AppDBConStr")
            'Return "Provider=Microsoft.Jet.OLEDB.4.0; " _
            '& "User Id=Admin; Password=''; " _
            '& "Data Source= " 
            Return nvc("AppDBConStr") & System.Web.HttpContext.Current.Server.MapPath("~/Data/EventsMgmt.mdb")

        End Get
    End Property


    '*********************************************************************
    ' Current Template String Property
    ' Returns the Name of the current template to be used
    '*********************************************************************
    Public Shared ReadOnly Property CurrentTemplate() As String
        Get
            Dim nvc As NameValueCollection = CType(ConfigurationSettings.GetConfig("Config" & ConfigurationHandler.CurrentConfig & "/AppTemplate"), NameValueCollection)
            Return nvc("CurTemplate")
        End Get
    End Property

    '*********************************************************************
    ' Email Server Address String Property
    ' Returns the Address of the SMTP Server to be used for sending Mails
    '*********************************************************************
    Public Shared ReadOnly Property EmailServerAddress() As String
        Get
            Dim nvc As NameValueCollection = CType(ConfigurationSettings.GetConfig("Config" & ConfigurationHandler.CurrentConfig & "/AdministrativeSettings"), NameValueCollection)
            Return nvc("EmailServer")
        End Get
    End Property


    '*********************************************************************
    ' Application Email String Property
    ' Returns the Email Address that the Application uses to send Emails
    '*********************************************************************
    Public Shared ReadOnly Property ApplicationEmail() As String
        Get
            Dim nvc As NameValueCollection = CType(ConfigurationSettings.GetConfig("Config" & ConfigurationHandler.CurrentConfig & "/AdministrativeSettings"), NameValueCollection)
            Return nvc("AppEmailAddress")
        End Get
    End Property


    '*********************************************************************
    ' Email Name String Property
    ' Returns the Email Name that the Application uses to send Emails
    '*********************************************************************
    Public Shared ReadOnly Property EmailName() As String
        Get
            Dim nvc As NameValueCollection = CType(ConfigurationSettings.GetConfig("Config" & ConfigurationHandler.CurrentConfig & "/AdministrativeSettings"), NameValueCollection)
            Return nvc("EmailName")
        End Get
    End Property


    '*********************************************************************
    ' Error Address String Property
    ' Returns the Email Address that Application Error Notification will be sent to
    '*********************************************************************
    Public Shared ReadOnly Property ErrorAddress() As String
        Get
            Dim nvc As NameValueCollection = CType(ConfigurationSettings.GetConfig("Config" & ConfigurationHandler.CurrentConfig & "/AdministrativeSettings"), NameValueCollection)
            Return nvc("ErrorEmailAddress")
        End Get
    End Property


    '*********************************************************************
    ' Contact Information String Property
    ' Returns the contact information of the application
    '*********************************************************************
    Public Shared ReadOnly Property ContactInformation() As String
        Get
            Return ConfigurationSettings.AppSettings.Item("ContactInformation")
        End Get
    End Property


    '*********************************************************************
    ' Error Redirect Page String Property
    ' Returns the Page Address for Error redirection
    '*********************************************************************
    Public Shared ReadOnly Property ErrorRedirectPage() As String
        Get
            Return ConfigurationSettings.AppSettings.Item("CustomErrorPage")
        End Get
    End Property


End Class

#End Region


End Namespace
