Imports System
Imports System.IO
Imports System.Web.UI
Imports OVBiz = OverSight.Business

Public Class BaseTemplatePage
    Inherits System.Web.UI.Page

    Protected NavRW As New TableRow
    Protected NavCell As New TableCell
    Protected hasNav As Boolean = False


#Region " Overide the OnInit on the System.Web.UI.Page "

    Protected Sub CallBaseOnInit(ByVal e As System.EventArgs)
        MyBase.OnInit(e)
    End Sub

    Protected Overrides Sub OnInit(ByVal e As System.EventArgs)
        '1. Load the HTML from the template file
        '2. then Move the Controls so that at design time they are under the Form tag
        '3. then Load the OnInit Event of my Base Class
        Me.LoadTemplateFile()
        Me.MoveControls()

        Me.Description = "Lubbock, Lubbock CVB, Calendar, Calendar of Events"
        Me.Title = "LubbockCVB::Online Calendar"

        MyBase.OnInit(e)
    End Sub

#End Region


#Region "Load Template File"

    Protected Overridable Sub LoadTemplateFile()

        'Loop Counter
        Dim ct As Integer = 0

        Dim strData As New System.Text.StringBuilder

        'The Literal Control that will be used to render the Stuff on the Page
        Dim LitC As LiteralControl

        'Opens a File Stream
        Dim FileReader As TextReader
        Dim ReadLine As String

        Dim startIdx As Integer = 0
        Dim taglen As Integer = 0

        If Me.Cache.Item("strData") Is Nothing Then
            FileReader = File.OpenText(Server.MapPath("~/templates/" & Me.TemplateName & "/" & Me.TemplateName & ".html"))
        Else
            FileReader = new StringReader(Cstr(Me.Cache.Item("strData")))
        End If


        'Prime the While Loop then Read the File while making sure 
        'that the File is still being read.
        ReadLine = FileReader.ReadLine()
        strData.Append(ReadLine & Environment.NewLine)
        Do

            If ReadLine.IndexOf("<!--TitleTag-->") >= 0 Then
                '1. Read the Line, check if the the Line is a Title/Meta Tag Place Holder
                '1.a if it is then load the the Title/Meta Tag Controls to the ControlsCollection
                baseTitle = New HtmlGenericControl("title")
                baseTitle.ID = "baseTitle"
                Me.Controls.Add(baseTitle)

                baseDescription = New HtmlGenericControl("meta")
                baseDescription.ID = "baseDescription"
                baseDescription.Attributes("name") = "description"
                Me.Controls.Add(baseDescription)

                LitC = New LiteralControl("<LINK rel=""stylesheet"" href=""" & Me.StyleSheet & """>")
                LitC.ID = "baseCss"
                Me.Controls.Add(LitC)

                startIdx = ReadLine.IndexOf("<!--TitleTag-->")
                taglen = ReadLine.LastIndexOf("<!--TitleTag-->")

            ElseIf ReadLine.IndexOf("<!--Navigation-->") >= 0 Then
                '2. Check if the Line is a Navigation Place Holder
                '2.a if it is then load the the Navigation User Control to the ControlsCollection
                If File.Exists(Server.MapPath("~/templates/" & Me.TemplateName & "/Navigation.ascx")) Then
                    Me.NavCell = New TableCell
                    Me.NavRW = New TableRow

                    Me.NavCell.Controls.Add(Page.LoadControl("~/templates/" & Me.TemplateName & "/Navigation.ascx"))
                    Me.NavCell.Controls.Item(0).ID = "NavControl"
                    Me.NavCell.ID = "baseNavControl"
                    Me.NavRW.Controls.Add(Me.NavCell)
                    Me.hasNav = True
                    'ReadLine.Replace("<!--Navigation-->", "")
                End If

            ElseIf ReadLine.IndexOf("<!--Content-->") >= 0 Then
                '3. Check if the Line is a Content Pane Place Holder
                '3.a if it is then load the the Navigation User Control to the ControlsCollection
                'Create a Form for the Page
                f = New HtmlForm
                f.Name = "BaseForm"
                f.ID = "BaseForm"


                Dim tbl As New Table
                tbl.CellPadding = 0
                tbl.CellSpacing = 0
                tbl.BorderStyle = BorderStyle.None
                tbl.Width = Unit.Pixel(800)
                tbl.HorizontalAlign = HorizontalAlign.Center

                Dim rw As New TableRow
                clContent = New TableCell
                clContent.Width = Unit.Percentage(100)
                clContent.VerticalAlign = VerticalAlign.Top
                clContent.CssClass = "ContentArea"
                clContent.Controls.Add(New LiteralControl("<br>"))
                rw.Cells.Add(clContent)

                Dim rw2 As New TableRow
                clContent = New TableCell
                clContent.Width = Unit.Percentage(100)
                clContent.VerticalAlign = VerticalAlign.Top
                clContent.CssClass = "ContentArea"
                clContent.Controls.Add(Page.LoadControl("~/templates/" & Me.TemplateName & "/Navigation.ascx"))
                rw2.Cells.Add(clContent)


                tbl.Rows.Add(rw2)
                tbl.Rows.Add(rw)

                f.Controls.Add(tbl)
                Me.Controls.Add(f)
                'ReadLine.Replace("<!--Content-->", "")
            Else

                '4. Then the Line must be part of the HTML Template so just render it to the broswer using the Literal Control
                Dim tmpStr As String = Server.HtmlEncode(ReadLine)
                Dim pathStr = "../templates/" & Me.TemplateName & "/"
                If Len(ReadLine.Length > 0) Then tmpStr = Replace(tmpStr, "src=&quot;", "src=&quot;" & pathStr)
                If Len(ReadLine.Length > 0) Then tmpStr = Replace(tmpStr, "background=&quot;", "background=&quot;" & pathStr)


                LitC = New LiteralControl(Server.HtmlDecode(tmpStr))
                LitC.ID = "baseTemplate" & ct.ToString()
                Me.Controls.Add(LitC)

            End If

            'Read the Next Line for the While Loop and Increment the Loop Counter
            ReadLine = FileReader.ReadLine()
            strData.Append(ReadLine & Environment.NewLine)
            ct += 1
        Loop While (FileReader.Peek() > 0)

        'Close the Stream afterwards
        FileReader.Close()

        If Me.Cache.Item("strData") Is Nothing Then Me.Cache.Item("strData") = strData.ToString

    End Sub

#End Region

#Region " MoveControls to the Content Area"
    Protected Sub MoveControls()
        Dim ph As Integer = 0
        While Me.Controls.Count > ph
            If Left(Me.Controls(ph).ID, 4).ToLower() <> "base" Then
                clContent.Controls.Add(Me.Controls(ph))
            Else
                ph += 1
            End If
        End While
    End Sub
#End Region

#Region "Template Properties -> Template Name, e.t.c"
    Public ReadOnly Property TemplateName() As String
        Get
            Return OVBiz.Utility.ConfigurationHandler.CurrentTemplate
        End Get
    End Property

#End Region

#Region "The HTML Form, Description Meta Tag, Title Meta Tag, and Content Area Table"

#Region " StyleSheet "
    Protected ReadOnly Property StyleSheet() As String
        Get
            Return "../templates/" & Me.TemplateName & "/StyleSheet.css"
        End Get
    End Property
#End Region

#Region " The HTML Form "
    Protected f As HtmlForm
    Protected ReadOnly Property Form() As HtmlForm
        Get
            Return f
        End Get
    End Property
#End Region

#Region " The Description Meta Tag"
    Protected baseDescription As HtmlGenericControl
    Protected Property Description() As String
        Get
            'Return baseDescription.Attributes("content")
            Return "Lubbock, Events, Calendar, CVB"
        End Get
        Set(ByVal Value As String)
            Try
                baseDescription.Attributes("content") = Value
            Catch
            End Try
        End Set
    End Property
#End Region

#Region " The Title Meta Tag"
    Protected baseTitle As HtmlGenericControl
    Public Property Title() As String
        Get
            'Return baseTitle.InnerText
            Return "Lubbock Events"
        End Get
        Set(ByVal Value As String)
            Try
                baseTitle.InnerText = Value
            Catch
            End Try
        End Set
    End Property
#End Region

#Region " ContentArea "
    Public clContent As TableCell
    Protected ReadOnly Property ContentArea() As TableCell
        Get
            Return clContent
        End Get
    End Property
#End Region

#End Region

#Region "Focus Handler"
    Public Sub SetControlFocus(ByVal ControlID As String)

        Page.RegisterClientScriptBlock("setFocus", _
        "<script type=""text/javascript"" language=""Javascript"">" & _
        " function setFocus() { document.forms[0]." & ControlID & ".focus() }" & _
        "</script> ")

        Page.RegisterClientScriptBlock("trapKeyPress", _
        "<script type=""text/javascript"" language=""Javascript"">" & _
        " function trapKeyPress() { if (window.event.keyCode == 13){ setFocus() } }" & _
        "</script> ")

    End Sub
    Public Sub SetNewLineTrap(ByRef theControl As WebControl)
        theControl.Attributes.Add("onKeyPress", "trapKeyPress()")
    End Sub
#End Region


End Class
